# Description
Export the Robertson example model to SBML using the SbmlExporter class.

# Code
```
from pysb.examples.robertson import model

from pysb.examples.robertson import model
from pysb.export.sbml import SbmlExporter
e = SbmlExporter(model)

```
